@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -59,9 +59,14 @@ public final class DefaultSpamHandler extends SpamHandler {
         super();
     }
 
-    private <V> V getPropertyFromView(ConfigView view, String propertyName, V defaultValue, Class<V> clazz) throws OXException {
+    private static <V> V getPropertyFromView(ConfigView view, String propertyName, V defaultValue, Class<V> clazz) throws OXException {
         ComposedConfigProperty<V> property = view.property(propertyName, clazz);
-        return (null != property && property.isDefined()) ? property.get() : defaultValue;
+        if (null == property) {
+            return defaultValue;
+        }
+
+        V value = property.get();
+        return value == null ? defaultValue : value;
     }
 
     @Override
